phonesrv_plat/converged_call_engine_api/inc/cccecallparameters.h
branchRCL_3
changeset 19 7d48bed6ce0c
parent 0 ff3b6d0fd310
child 20 987c9837762f
--- a/phonesrv_plat/converged_call_engine_api/inc/cccecallparameters.h	Thu Aug 19 10:28:14 2010 +0300
+++ b/phonesrv_plat/converged_call_engine_api/inc/cccecallparameters.h	Tue Aug 31 15:45:17 2010 +0300
@@ -87,7 +87,11 @@
         /** Gets the origin of the call. */
         virtual TCCECallOrigin Origin() const;
 
-
+        /** Sets the SAT alpha id identifying the text to be shown instead of number in         
+            call bubble */
+        virtual void SetAlphaId(TBuf<KCCPAlphaIdMaxSize> aAlphaId);
+        /** Gets the SAT alpha id of the call. */
+        virtual TBuf<KCCPAlphaIdMaxSize> AlphaId() const;
     
     protected:
        CCCECallParameters();
@@ -102,11 +106,13 @@
         TBuf<KCCPUUSIdSize> iUUSId;
         /** Capability configuration parameters for the first bearer. */
         TBuf8<KCCEBearerMaxSize> iBearer;
-    	/** A buffer to hold the sub-address of a telephone number.  */
-    	TBuf<KCCESubAddressMaxSize> iSubAddress;
-    	/** Call origin.  */
-    	TCCECallOrigin iOrigin;
-	
+        /** A buffer to hold the sub-address of a telephone number.  */
+        TBuf<KCCESubAddressMaxSize> iSubAddress;
+        /** Call origin.  */
+        TCCECallOrigin iOrigin;
+        /** Alpha id.  */
+        TBuf<KCCPAlphaIdMaxSize> iAlphaId;
+    
     };
 
 #endif
\ No newline at end of file